@@ -21,7 +21,7 @@
 #'
 #' If type == "expression"
 #' \itemize{
-#'   \item{style is a Style object. See \code{\link{createStyle}}}
+#'   \item{style is a Style object. See [createStyle()]}
 #'   \item{rule is an expression. Valid operators are "<", "<=", ">", ">=", "==", "!=".}
 #' }
 #'
@@ -37,56 +37,56 @@
 #'   \item{rule is a numeric vector specifying the range of the databar colours. Must be equal length to style}
 #'   \item{...
 #'   \itemize{
-#'     \item{\bold{showvalue} If FALSE the cell value is hidden. Default TRUE.}
-#'     \item{\bold{gradient} If FALSE colour gradient is removed. Default TRUE.}
-#'     \item{\bold{border} If FALSE the border around the database is hidden. Default TRUE.}
+#'     \item{**showvalue** If FALSE the cell value is hidden. Default TRUE.}
+#'     \item{**gradient** If FALSE colour gradient is removed. Default TRUE.}
+#'     \item{**border** If FALSE the border around the database is hidden. Default TRUE.}
 #'      }
 #'    }
 #' }
 #'
 #' If type == "duplicates"
 #' \itemize{
-#'   \item{style is a Style object. See \code{\link{createStyle}}}
+#'   \item{style is a Style object. See [createStyle()]}
 #'   \item{rule is ignored.}
 #' }
 #'
 #' If type == "contains"
 #' \itemize{
-#'   \item{style is a Style object. See \code{\link{createStyle}}}
+#'   \item{style is a Style object. See [createStyle()]}
 #'   \item{rule is the text to look for within cells}
 #' }
 #'
 #' If type == "between"
 #' \itemize{
-#'   \item{style is a Style object. See \code{\link{createStyle}}}
+#'   \item{style is a Style object. See [createStyle()]}
 #'   \item{rule is a numeric vector of length 2 specifying lower and upper bound (Inclusive)}
 #' }
 #'
 #' If type == "topN"
 #' \itemize{
-#'   \item{style is a Style object. See \code{\link{createStyle}}}
+#'   \item{style is a Style object. See [createStyle()]}
 #'   \item{rule is ignored}
 #'   \item{...
 #'   \itemize{
-#'     \item{\bold{rank} numeric vector of length 1 indicating number of highest values.}
-#'     \item{\bold{percent} TRUE if you want top N percentage.}
+#'     \item{**rank** numeric vector of length 1 indicating number of highest values.}
+#'     \item{**percent** TRUE if you want top N percentage.}
 #'      }
 #'    }
 #' }
 #' 
 #' If type == "bottomN"
 #' \itemize{
-#'   \item{style is a Style object. See \code{\link{createStyle}}}
+#'   \item{style is a Style object. See [createStyle()]}
 #'   \item{rule is ignored}
 #'   \item{...
 #'   \itemize{
-#'     \item{\bold{rank} numeric vector of length 1 indicating number of lowest values.}
-#'     \item{\bold{percent} TRUE if you want bottom N percentage.}
+#'     \item{**rank** numeric vector of length 1 indicating number of lowest values.}
+#'     \item{**percent** TRUE if you want bottom N percentage.}
 #'      }
 #'    }
 #' }
 #' 
-#' @seealso \code{\link{createStyle}}
+#' @seealso [createStyle()]
 #' @export
 #' @examples
 #' wb <- createWorkbook()
@@ -294,9 +294,8 @@ conditionalFormatting <-
            style = NULL,
            type = "expression",
            ...) {
-    od <- getOption("OutDec")
-    options("OutDec" = ".")
-    on.exit(expr = options("OutDec" = od), add = TRUE)
+    op <- get_set_options()
+    on.exit(options(op), add = TRUE)
 
     type <- tolower(type)
     params <- list(...)
